@@ -3,22 +3,19 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
+ * The contents of this file constitute Original Code as defined in and
+ * are subject to the Apple Public Source License Version 1.1 (the
+ * "License").  You may not use this file except in compliance with the
+ * License.  Please obtain a copy of the License at
+ * http://www.apple.com/publicsource and read it before using this file.
  * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
- * 
- * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This Original Code and all software distributed under the License are
+ * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
- * limitations under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
+ * License for the specific language governing rights and limitations
+ * under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -317,4 +314,159 @@ IOATABusCommand::setCommandInUse( bool inUse /* = true */)
 
 }
 
+#pragma mark -- IOATABusCommand64 --
 
+#undef super 
+
+#define super IOATABusCommand
+
+OSDefineMetaClassAndStructors( IOATABusCommand64, super )
+
+/*-----------------------------------------------------------------------------
+ *  Static allocator.
+ *
+ *-----------------------------------------------------------------------------*/
+IOATABusCommand64* 
+IOATABusCommand64::allocateCmd32(void)
+{
+	IOATABusCommand64* cmd = new IOATABusCommand64;
+	
+	if( cmd == 0L)
+		return 0L;
+		
+		
+	if( ! cmd->init() )
+	{
+		cmd->free();
+		return 0L;
+	}
+		
+		
+	return cmd;
+	
+}
+
+/*-----------------------------------------------------------------------------
+ *
+ *
+ *-----------------------------------------------------------------------------*/
+bool
+IOATABusCommand64::init()
+{
+	if( ! super::init() )
+		return false;
+
+	zeroCommand();
+
+	_dmaCmd = IODMACommand::withSpecification(IODMACommand::OutputHost32,
+								32,
+								0x10000,
+								IODMACommand::kMapped,
+								512 * 2048,
+								2);
+	
+
+	if( ! _dmaCmd )
+	{
+		return false;	
+	}
+
+	
+	return true;
+
+}
+
+/*-----------------------------------------------------------------------------
+ *
+ *
+ *-----------------------------------------------------------------------------*/
+void 
+IOATABusCommand64::zeroCommand(void)
+{
+	if(_dmaCmd != NULL)
+	{
+		if( _dmaCmd->getMemoryDescriptor() != NULL)
+		{
+			_dmaCmd->clearMemoryDescriptor();
+		}
+	}
+	
+	super::zeroCommand();
+
+}
+
+/*-----------------------------------------------------------------------------
+ *
+ *
+ *-----------------------------------------------------------------------------*/
+
+void 
+IOATABusCommand64::free()
+{
+
+	if( _dmaCmd != NULL )
+	{	
+		_dmaCmd->clearMemoryDescriptor();
+		_dmaCmd->release();
+		_dmaCmd = NULL;
+	}
+	
+	super::free();
+
+}
+
+void 
+IOATABusCommand64::setBuffer ( IOMemoryDescriptor* inDesc)
+{
+
+	super::setBuffer( inDesc );
+
+}
+
+void 
+IOATABusCommand64::executeCallback(void)
+{
+	if( _dmaCmd != NULL
+		&& _desc != NULL
+		&& ( _flags & mATAFlagUseDMA ) )
+	{	
+		_dmaCmd->complete();
+	}
+	
+	_dmaCmd->clearMemoryDescriptor();
+	
+	super::executeCallback();
+
+}
+
+
+IODMACommand* 
+IOATABusCommand64::GetDMACommand( void )
+{
+
+	return _dmaCmd;
+
+}
+
+void
+IOATABusCommand64::setCommandInUse( bool inUse /* = true */)
+{
+
+	if( inUse )
+	{
+	
+		if( _dmaCmd != NULL
+			&& _desc != NULL
+			&& ( _flags & mATAFlagUseDMA ) )
+		{	
+			_dmaCmd->setMemoryDescriptor( _desc, true );
+		
+		
+		}
+	
+	
+	}
+
+	super::setCommandInUse( inUse);
+
+}
